@@ -62,18 +62,14 @@ pub mod janus_edge_auth;
 pub use self::janus_edge_auth::JanusEdgeAuth;
 pub mod janus_edge_auth_request;
 pub use self::janus_edge_auth_request::JanusEdgeAuthRequest;
+pub mod janus_task;
+pub use self::janus_task::JanusTask;
+pub mod janus_task_request;
+pub use self::janus_task_request::JanusTaskRequest;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
 pub use self::model_artifact::ModelArtifact;
-pub mod monitor_start_task;
-pub use self::monitor_start_task::MonitorStartTask;
-pub mod monitor_start_task_request;
-pub use self::monitor_start_task_request::MonitorStartTaskRequest;
-pub mod monitor_stop_task;
-pub use self::monitor_stop_task::MonitorStopTask;
-pub mod monitor_stop_task_request;
-pub use self::monitor_stop_task_request::MonitorStopTaskRequest;
 pub mod octo_generic_event;
 pub use self::octo_generic_event::OctoGenericEvent;
 pub mod octo_job_event;
@@ -290,16 +286,14 @@ pub mod system_info_request;
 pub use self::system_info_request::SystemInfoRequest;
 pub mod task;
 pub use self::task::Task;
-pub mod task_request;
-pub use self::task_request::TaskRequest;
 pub mod task_status;
 pub use self::task_status::TaskStatus;
 pub mod task_status_request;
 pub use self::task_status_request::TaskStatusRequest;
 pub mod task_status_status_enum;
 pub use self::task_status_status_enum::TaskStatusStatusEnum;
-pub mod tasktype_enum;
-pub use self::tasktype_enum::TasktypeEnum;
+pub mod task_type_enum;
+pub use self::task_type_enum::TaskTypeEnum;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_polymorphic;
